@@ -1,18 +1,13 @@
 ## builtin imports
 import os
-import sys 
-import h5py
-import matplotlib 
-matplotlib.use('Agg') 
 import numpy as np 
 import ctypes
 import copy
 
-import matplotlib.pyplot as plt
 
 ## abg_python imports
-from abg_python import filterDictionary,append_function_docstring,append_string_docstring
-from abg_python.plot_utils import addColorbar,get_cmap
+from abg_python import append_function_docstring,append_string_docstring
+from abg_python.plot_utils import plt,addColorbar,get_cmap
 from abg_python.galaxy.metadata_utils import metadata_cache
 
 ## firestudio imports
@@ -22,7 +17,7 @@ def vfloat(x):
     return x.ctypes.data_as(ctypes.POINTER(ctypes.c_float))
 
 class GasStudio(Studio):
-    """`FIREstudio` class for making gas projection images.
+    """ `FIREstudio` class for making gas projection images.
         Can be used for stars, but you will either have to pass smoothing lengths
         in or allow FIREstudio to calculate them itself, which  can take a long time. 
 
@@ -33,39 +28,55 @@ Important methods include:
 * [`Studio.__init__`](#studio__init__) 
 * [`Studio.set_ImageParams`](#studioset_imageparams)"""
 
+
+    required_snapdict_keys = ['Coordinates','Masses','SmoothingLength','Temperature','Velocities']
+
     def __repr__(self):
+        """ implementation of built-in __repr__ method for printing.
+
+        Returns
+        -------
+        str
+            string to print back to the console
+        """
         return 'GasStudio instance'
 
     def set_ImageParams(
         self,
-        use_defaults=False,
-        loud=True,
+        use_defaults:bool=False,
+        loud:bool=True,
         **kwargs):
-        """Changes the parameters of the image. If `use_defaults=True` then 
-            default values of the parameters will be set. Leave `use_defaults=False`
-            to adjust only the keywords passed. 
+        """ Changes the parameters of the image such as camera orientation, frame size, etc. 
+            If `use_defaults=True` then default values of the parameters will be set and will 
+            overwrite the current state. Leave `use_defaults=False` to adjust only the keywords passed. 
 
-            Input: 
+        Parameters
+        ----------
+        use_defaults : bool, optional
+            overwrite current state with default values of each parameter, useful for initialization
+            or resetting after making changes, by default False
+        loud : bool, optional
+            flag to print which parameters are being set/updated, by default True
 
-                use_defaults = False -- 
-                loud = True -- 
+        Keywords
+        --------
+            use_colorbar: bool, optional
+                flag to add a colorbar to the image. not currently implemented for 
+                two-color images, by default False
+            cbar_label: str, optional
+                label for the colorbar, by default ''
+            cbar_logspace: bool, optional
+                flag for whether ticks on the colorbar should be log-spaced, by default False
 
-                use_colorbar = False -- 
-                cbar_label = '' -- 
-                cbar_logspace = False -- 
 
-            Output:
-
-                None
-
-Example usage:
-```python 
-gasStudio.set_ImageParams(
-    use_colorbar=True,
-    cbar_label='Temperature',
-    cbar_logspace=True,
-    figure_label='t = 13.8 Gyr')
-```"""
+        Example usage
+        -------------
+        ```python 
+        gasStudio.set_ImageParams(
+            use_colorbar=True,
+            cbar_label='Temperature',
+            cbar_logspace=True,
+            figure_label='t = 13.8 Gyr')```"""
 
         default_kwargs = {
             'use_colorbar':False,
@@ -92,8 +103,9 @@ gasStudio.set_ImageParams(
             else:
                 if (kwarg not in Studio.set_ImageParams.default_kwargs
                     and kwarg != 'this_setup_id'):
-                    print(kwarg,'ignored. Did you mean something else?',
-                        default_kwargs.keys())
+                    if self.master_loud:
+                        print(kwarg,'ignored. Did you mean something else?',
+                            default_kwargs.keys())
 
         if use_defaults:
             ## set the remaining image parameters to their default values
@@ -119,15 +131,7 @@ gasStudio.set_ImageParams(
 
 
     def print_ImageParams(self):
-        """ Prints current image setup to console.
-
-            Input:
-
-                None
-
-            Output:
-
-                None """
+        """ Prints the current image parameters."""
 
         default_kwargs = {
             'use_colorbar':False,
@@ -142,91 +146,65 @@ gasStudio.set_ImageParams(
         ## call the super class' print image params
         super().print_ImageParams()
 
-    def __quick_weightAvgAlongLOS(
+    def projectAlongLOS(
         self,
-        weights,
-        weight_name,
-        quantities,
-        quantity_name,
-        snapdict_name='gas',
-        **kwargs):
-
-        (BoxSize,
-        Xmin,Xmax,
-        Ymin,Ymax,
-        Zmin,Zmax,
-        npix_x,npix_y,
-        prep_pos,prep_weights,prep_quantities,
-        prep_hsml) = self.__prepareCoordinates(
-            snapdict_name,
-            weights,
-            weight_name,
-            quantities,
-            quantity_name)
-
-        xedges = np.linspace(Xmin,Xmax,npix_x,endpoint=True)
-        yedges = np.linspace(Ymin,Ymax,npix_y,endpoint=True)
-
-        xs,ys,zs = prep_pos.T
-        weightMap,xedges,yedges = np.histogram2d(
-            xs,ys,
-            bins=[xedges,yedges],
-            weights=prep_weights)
-
-        weightWeightedQuantityMap,xedges,yedges = np.histogram2d(
-            xs,ys,
-            bins=[xedges,yedges],
-            weights=prep_weights*prep_quantities)
-
-        return weightMap, weightWeightedQuantityMap/weightMap
-
-
-    def weightAvgAlongLOS(
-        self,
-        weights,
-        weight_name,
-        quantities,
-        quantity_name,
-        use_metadata=True,
-        save_meta=True,
-        assert_cached=False,
-        loud=True,
+        weights:np.ndarray,
+        weight_name:str,
+        quantities:np.ndarray,
+        quantity_name:str,
+        use_metadata:bool=True,
+        save_meta:bool=True,
+        assert_cached:bool=False,
+        loud:bool=True,
         **kwargs, 
         ):
         """Projects a weighted quantity along the LOS into pixels. Projection is 
             done with a cubic spline kernel that is renormalized to conserve mass. 
 
-I.e. 
+        I.e. 
 
-`renorm_i = sum_j ( k(r_ij,h_i))`
+        `renorm_i = sum_j ( k(r_ij,h_i))`
 
-where j is a sum over the pixels particle i contributes to.
+        where j is a sum over the pixels particle i contributes to.
 
-The maps computed in pixel j are then:
+        The maps computed in the flattened pixel array at index j are then:
 
-`W[j] = sum_i( k(r_ij,h_i)/renorm_i * weight)`
-`Q[j] = sum_i( k(r_ij,h_i)/renorm_i * weight * quantity) / W[j]`
+        `W[j] = sum_i( k(r_ij,h_i)/renorm_i * weight)`
+        `Q[j] = sum_i( k(r_ij,h_i)/renorm_i * weight * quantity) / W[j]`
 
-            Input:
+        Parameters
+        ----------
+        weights : np.ndarray, optional
+            array of weights to use alongside the smoothing kernel
+            (typically `self.snapdict['Masses']`).
+        weight_name : str
+            Name of the key in the snapdict that should be used as the weights
+            if weights are not passed.
+            special weight_names are `Volumes` and `Ones`, which do not 
+            have to be present in the snapdict.
+        quantities : np.ndarray, optional
+            array of quantities to project along the line of sight.
+        quantity_name : str
+            Name of the field that is being projected, should be in the snapdict if 
+            quantities is not passed.
+        use_metadata : bool, optional
+            flag for whether a cached result should be used (if it exists), by default True
+        save_meta : bool, optional
+            flag to save the result in the cache, by default True
+        assert_cached : bool, optional
+            flag to require a cache hit and raise an exception otherwise, by default False
+        loud : bool, optional
+            flag for whether cache hits/misses should be announced
+            to the console., by default True
 
-                weights --
-                weight_name -- 
-                    special weight_names are `Volumes` and `Ones`, which do not 
-                    have to be present in the snapdict to be used as weights.
-                quantities --
-                quantity_name --
-                use_metadata=True --
-                save_meta=True --
-                assert_cached=False --
-                loud=True --
-                
-                snapdict_name -- 'gas' or 'star', where to load arrays that hasn't 
-                    been passed from
-
-            Output:
-
-                weightMap -- 
-                weightWeightedQuantityMap --"""
+        Returns
+        -------
+        weightMap: np.ndarray
+            image of sum(weights) along the line of sight in each pixel
+        weightWeightedQuantityMap: np.ndarray
+            image of sum(weights*quantity) along the line of sight in each pixel
+        """
+        
 
         @metadata_cache(
             self.this_setup_id,  ## hdf5 file group name
@@ -239,13 +217,13 @@ The maps computed in pixel j are then:
             assert_cached=assert_cached,
             loud=loud,
             force_from_file=True) ## read from cache file, not attribute of object
-        def inner_weight_along_los(
-            self,
-            weights,
-            weight_name,
-            quantities,
-            quantity_name,
-            snapdict_name='gas'):
+        def inner_projectAlongLOS(
+            self:GasStudio,
+            weights:np.ndarray,
+            weight_name:str,
+            quantities:np.ndarray,
+            quantity_name:str,
+            snapdict_name:str='gas'):
 
             ## make the actual C call
             weightMap, weightWeightedQuantityMap = getImageGrid(
@@ -262,7 +240,7 @@ The maps computed in pixel j are then:
 
             return weightMap, weightWeightedQuantityMap
 
-        return inner_weight_along_los(
+        return inner_projectAlongLOS(
             self,
             weights,
             weight_name,
@@ -272,17 +250,61 @@ The maps computed in pixel j are then:
 
     def __prepareCoordinates(
         self,
-        snapdict_name,
-        weights,
-        weight_name,
-        quantities,
-        quantity_name):
-        """ keys required to function:
-            Coordinates
-            SmoothingLength (optional, will compute though otherwise)
-            weight_name (unless it's Ones or passed in as weights)
-            quantity_name (unless it's passed in as quantities)
+        snapdict_name:str,
+        weights:np.ndarray,
+        weight_name:str,
+        quantities:np.ndarray,
+        quantity_name:str):
+        """ 
+
+        Parameters
+        ----------
+        snapdict_name : str
+            [description]
+        weights : np.ndarray
+            array of weights to use alongside the smoothing kernel
+            (typically `self.snapdict['Masses']`).
+        weight_name : str
+            Name of the key in the snapdict that should be used as the weights
+            if weights are not passed.
+            special weight_names are `Volumes` and `Ones`, which do not 
+            have to be present in the snapdict.
+        quantities : np.ndarray
+            array of quantities to project along the line of sight.
+        quantity_name : str
+            Name of the field that is being projected, should be in the snapdict if 
+            quantities is not passed.
+
+        Returns
+        -------
+        self.Xmin : float
+            minimum x value of coordinates, already applied just returned for convenience
+        self.Xmax : float
+            maximum x value of coordinates, already applied just returned for convenience
+        self.Ymin : float
+            minimum y value of coordinates, already applied just returned for convenience
+        self.Ymax : float
+            maximum y value of coordinates, already applied just returned for convenience
+        self.npix_x : float
+            number of pixels along the x axis
+        self.npix_y : float
+            number of pixels along the y axis
+        pos : np.ndarray
+            coordinate data for particles in kpc 
+        weights : np.ndarray
+            filtered array of weights to use alongside the smoothing kernel
+            (typically `self.snapdict['Masses']`).
+        quantities : np.ndarray
+            filtered array of quantities to project along the line of sight.
+        hsml : np.ndarray
+            filtered array of smoothing lengths/radii for each particle
+
+        Raises
+        ------
+        KeyError
+            if `snapdict_name` is not `'gas'` or `'star'`
         """
+        
 
         ## pick which particle type we're projecting, 
         if snapdict_name != 'gas' and snapdict_name != 'star':
@@ -303,7 +325,6 @@ The maps computed in pixel j are then:
 
         if "SmoothingLength" not in snapdict:
             Hsml = self.get_HSML(snapdict_name)
-            assert type(Hsml) == np.ndarray
             if 'masked_' in full_snapdict_name:
                 Hsml = Hsml[self.mask]
         else:
@@ -346,212 +367,210 @@ The maps computed in pixel j are then:
             else:
                 quantities = snapdict[quantity_name]
 
-        ## rotate by euler angles if necessary
-        pos = self.camera.rotate_array(Coordinates,offset=True)
-
         ## cull the particles outside the frame and cast to float32
-        box_mask = self.cullFrameIndices(pos)
+        pos,box_mask = self.camera.project_and_clip(pos)
 
-        if self.master_loud:
-            print("projecting %d particles"%np.sum(box_mask))
+        if self.master_loud: print("projecting %d particles"%np.sum(box_mask))
 
-        pos = pos[box_mask].astype(np.float32)
         weights = weights[box_mask].astype(np.float32)
         quantities = quantities[box_mask].astype(np.float32)
         hsml = Hsml[box_mask].astype(np.float32)
 
         return (
-            BoxSize,
             self.Xmin,self.Xmax,
             self.Ymin,self.Ymax,
-            self.Zmin,self.Zmax,
             self.npix_x,self.npix_y,
             pos,weights,quantities,
             hsml)
 
-        if self.master_loud:
-            print('-done')
-
-    def volumeWeightAlongLOS(
+    def __quick_projectAlongLOS(
         self,
-        quantity,
-        quantity_name, 
+        weights:np.ndarray,
+        weight_name:str,
+        quantities:np.ndarray,
+        quantity_name:str,
+        snapdict_name='gas',
+        loud:bool=True,
         **kwargs):
-        """Wrapper function for easier API if quantity = None 
-            but quantity_name is in the snapdict then it will be read for you.
+        """ approximates the projection of a weighted quantity along the LOS into pixels.
+            using a 2d histogram and assuming particles have 0 extent. much faster than the 
+            real thing and useful for quick and dirty testing.
 
-            Volume is calculated as 4/3 pi hsml^3 / 32.
-            If you'd like a different volume weight then set self.gas_snapdict['Volume'] = volumes.
+        Parameters
+        ----------
+        weights : np.ndarray, optional
+            array of weights to use alongside the smoothing kernel
+            (typically `self.snapdict['Masses']`).
+        weight_name : str
+            Name of the key in the snapdict that should be used as the weights
+            if weights are not passed.
+            special weight_names are `Volumes` and `Ones`, which do not 
+            have to be present in the snapdict.
+        quantities : np.ndarray, optional
+            array of quantities to project along the line of sight.
+        quantity_name : str
+            Name of the field that is being projected, should be in the snapdict if 
+            quantities is not passed.
+        use_metadata : bool, optional
+            flag for whether a cached result should be used (if it exists), by default True
+        save_meta : bool, optional
+            flag to save the result in the cache, by default True
+        assert_cached : bool, optional
+            flag to require a cache hit and raise an exception otherwise, by default False
+        loud : bool, optional
+            flag for whether cache hits/misses should be announced
+            to the console., by default True
 
-            Alternatively, call weightAvgAlongLOS directly with quantity and weights passed.
+        Returns
+        -------
+        weightMap: np.ndarray
+            image of sum(weights) along the line of sight in each pixel
+        weightWeightedQuantityMap: np.ndarray
+            image of sum(weights*quantity) along the line of sight in each pixel
+        """
 
-            Input:
+        (Xmin,Xmax,
+        Ymin,Ymax,
+        npix_x,npix_y,
+        prep_pos,prep_weights,prep_quantities,
+        prep_hsml) = self.__prepareCoordinates(
+            snapdict_name,
+            weights,
+            weight_name,
+            quantities,
+            quantity_name)
 
-                quantity --
-                quantity_name --
+        xedges = np.linspace(Xmin,Xmax,npix_x,endpoint=True)
+        yedges = np.linspace(Ymin,Ymax,npix_y,endpoint=True)
 
-                use_metadata=True --
-                save_meta=True --
-                assert_cached=False --
-                loud=True --
+        xs,ys,_ = prep_pos.T
+        weightMap,xedges,yedges = np.histogram2d(
+            xs,ys,
+            bins=[xedges,yedges],
+            weights=prep_weights)
 
-                snapdict_name='gas' --
+        weightWeightedQuantityMap,xedges,yedges = np.histogram2d(
+            xs,ys,
+            bins=[xedges,yedges],
+            weights=prep_weights*prep_quantities)
 
-            Output: 
-
-                volumeMap -- a map of the deposited cell volume along the LOS
-                    in each pixel.
-                volumeWeightedQuantityMap -- the volume weighted quantity along the
-                    LOS in each pixel."""
-
-        return self.weightAvgAlongLOS(
-            None, ## read it from the snapdict
-            'Volume',
-            quantity,
-            quantity_name,
-            **kwargs)
-
-    def massWeightAlongLOS(
-        self,
-        quantity,
-        quantity_name,
-        **kwargs):
-        """ Wrapper function for easier API if quantity = None 
-            but quantity_name is in the snapdict then it will be read for you.
-
-            Input:
-
-                quantity -- 
-                quantity_name -- 
-
-                use_metadata=True -- 
-                save_meta=True -- 
-                assert_cached=False -- 
-                loud=True -- 
-                snapdict_name='gas' -- 
-            
-            Output:
-
-                massMap -- a map of the deposited cell mass along the LOS
-                    in each pixel.
-                massWeightedQuantityMap -- the mass weighted quantity along the
-                    LOS in each pixel."""
-
-
-        return self.weightAvgAlongLOS(
-            None, ## read it from the snapdict.
-            'Masses',
-            quantity,
-            quantity_name,
-            **kwargs)
+        return weightMap, weightWeightedQuantityMap/weightMap
 
 ####### produceImage implementation #######
-    def render(
-        self,
-        ax=None,
-        **kwargs):
-        """Plots a projected image using the stored image parameters.
-
-            Input: 
-
-                ax = None -- axis to plot image to, if None will create a new figure
-
-                weight_name = 'Masses' --
-                quantity_name = 'Temperature' --
-                weights = None -- 
-                quantities = None --
-                min_weight = None,max_weight = None --
-                min_quantity = None,max_quantity = None --
-                weight_adjustment_function = None --
-                quantity_adjustment_function = None --
-                use_colorbar = False --
-                cmap = 'viridis' -- what colormap to use
-                quick = False -- flag to use a simple 2d histogram (for comparison or
-                    for quick iteration as the user defines the image parameters)
-
-            Output:
-
-                ax -- the axis the image was plotted to
-                final_image -- 2x2x3 RGB pixel array
-
-Example usage:
-```python
-## makes a gas surface density map
-gasStudio.render(
-    weight_name='Masses',
-    min_weight=-0.1,
-    max_weight=1.5,
-    weight_adjustment_function= lambda x: np.log10(x/gasStudio.Acell)+10-6 ## log10(msun/pc^2)
-    )
-
-## makes a mass weighted temperature map
-gasStudio.render(
-    weight_name='Masses',
-    quantity_name='Temperature',
-    min_quantity=2,
-    max_quantity=7,
-    quantity_adjustment_function= np.log10
-    )
-
-## makes a saturation-hue gas surface density + Temperature map
-gasStudio.render(
-    weight_name='Masses',
-    min_weight=-0.1,
-    max_weight=1.5,
-    weight_adjustment_function= lambda x: np.log10(x/gasStudio.Acell)+10-6 ## log10(msun/pc^2)
-    quantity_name='Temperature',
-    min_quantity=2,
-    max_quantity=7,
-    quantity_adjustment_function= np.log10
-    ) 
-```"""
-
-
-        if ax is None:
-            fig,ax = plt.figure(),plt.gca()
-        else:
-            fig = ax.get_figure()
-
-        ## remap the C output to RGB space
-        final_image = self.produceImage(**kwargs)
-
-        ## plot that RGB image and overlay scale bars/text
-        self.plotImage(ax,final_image)
-
-        ## save the image
-        if self.savefig is not None:
-            self.saveFigure(ax,self.savefig)
-
-        return ax,final_image
-
     def produceImage(
         self,
-        weight_name='Masses',
-        quantity_name='Temperature',
-        weights=None,quantities=None,
-        min_weight=None,max_weight=None,
-        min_quantity=None,max_quantity=None,
+        weight_name:str='Masses',
+        quantity_name:str='Temperature',
+        weights:np.ndarray=None,quantities:np.ndarray=None,
+        min_weight:float=None,max_weight:float=None,
+        min_quantity:float=None,max_quantity:float=None,
         weight_adjustment_function=None,
         quantity_adjustment_function=None,
-        use_colorbar=False,
-        cmap='viridis', ## what colormap to use
-        quick=False,
+        cmap:str='viridis', ## what colormap to use
+        quick:bool=False,
         **kwargs
         ):
+        """ Generates a projected image using the stored image parameters.
+        Specify whether the image should be "one-color" (i.e. a simple projection map)
+        or "two-color" (a projection map where the hue is set by the
+        LOS projected weighted quantity and the saturation is set by the LOS projected weight)
+        by passing values for `min_weight`, `max_weight`, `min_quantity`, and `max_quantity`.
+
+        Parameters
+        ----------
+        weight_name : str, optional
+            Name of the key in the snapdict that should be used as the weights
+            if weights are not passed. Special weight_names are `Volumes` and `Ones`,
+            which do not have to be present in the snapdict, by default 'Masses'
+        quantity_name : str, optional
+            Name of the field that is being projected, should be in the snapdict if 
+            quantities is not passed, by default 'Temperature'
+        weights : np.ndarray, optional
+            array of weights to use alongside the smoothing kernel
+            (typically `self.snapdict['Masses']`). 
+            If None searches `self.snapdict` for `weight_name`, by default None
+        quantities : np.ndarray, optional
+            array of quantities to project along the line of sight.
+            If None searches `self.snapdict` for `weight_name`, by default None
+        min_weight : float, optional
+            minimum value to use for the colorbar of weight projection maps
+            and saturation for two-color images, by default None
+        max_weight : float, optional
+            maximum value to use for the colorbar of weight projection maps
+            and saturation for two-color images, by default None
+        min_quantity : float, optional
+            minimum value to use for the colorbar of weighted quantity projection maps
+            and hue for two-color images, by default None
+        max_quantity : float, optional
+            maximum value to use for the colorbar of weighted quantity projection maps
+            and hue for two-color images, by default None
+        weight_adjustment_function : function, optional
+            function to apply to the `weightMap` after it is
+            returned by `~firestudio.studios.gas_studio.GasStudio.projectAlongLOS`
+            for the purposes of specifying `min_weight` and `max_weight`, by default None
+        quantity_adjustment_function : function, optional
+            function to apply to the `weightWeightedQuantityMap` after it is
+            returned by `~firestudio.studios.gas_studio.GasStudio.projectAlongLOS`
+            for the purposes of specifying `min_quantity` and `max_quantity`, by default None
+        cmap : str, optional
+            name of colormap to apply to image, by default 'viridis'
+
+        Returns
+        -------
+        np.ndarray(npix_x,npix_y,3)
+            array of RGB image pixel values
+
+        Raises
+        ------
+        ValueError
+            if an invalid combination of min/max weight/quantity parameters are 
+            passed.
+
+        Example usage
+        -------------
+        ```python
+        ## makes a gas surface density map
+        gasStudio.render(
+            weight_name='Masses',
+            min_weight=-0.1,
+            max_weight=1.5,
+            weight_adjustment_function= lambda x: np.log10(x/gasStudio.Acell)+10-6 ## log10(msun/pc^2)
+            )
+
+        ## makes a mass weighted temperature map
+        gasStudio.render(
+            weight_name='Masses',
+            quantity_name='Temperature',
+            min_quantity=2,
+            max_quantity=7,
+            quantity_adjustment_function= np.log10
+            )
+
+        ## makes a saturation-hue gas surface density + Temperature map
+        gasStudio.render(
+            weight_name='Masses',
+            min_weight=-0.1,
+            max_weight=1.5,
+            weight_adjustment_function= lambda x: np.log10(x/gasStudio.Acell)+10-6 ## log10(msun/pc^2)
+            quantity_name='Temperature',
+            min_quantity=2,
+            max_quantity=7,
+            quantity_adjustment_function= np.log10
+            )```"""
 
         self.cmap = cmap
 
 
         ## load the requested maps
         if not quick:
-            weightMap, weightWeightedQuantityMap = self.weightAvgAlongLOS(
+            weightMap, weightWeightedQuantityMap = self.projectAlongLOS(
                 weights,
                 weight_name,
                 quantities,
                 quantity_name,
                 **kwargs)
         else:
-            weightMap, weightWeightedQuantityMap = self.__quick_weightAvgAlongLOS(
+            weightMap, weightWeightedQuantityMap = self.__quick_projectAlongLOS(
                 weights,
                 weight_name,
                 quantities,
@@ -624,8 +643,7 @@ gasStudio.render(
             self.cbar_min = min_quantity
             self.cbar_max = max_quantity
 
-        else:
-            raise ValueError("Use (min/max)_(weight/quantity) kwargs to set image")
+        else: raise ValueError("Use (min/max)_(weight/quantity) kwargs to set image")
 
         ## convert the images from 0->1 space to 0-> 255 space
         final_image = produce_cmap_hsv_image(image_Q, image_W, cmap=self.cmap) 
@@ -635,9 +653,22 @@ gasStudio.render(
 ####### plotImage implementation #######
     def plotImage(
         self,
-        ax,
-        final_image
-        ):
+        ax:plt.Axes,
+        final_image:np.ndarray):
+        """Implementation of overlaying artists on top of projected image.
+        if `self.use_colorbar==True`
+            we add a colorbar to the image
+        See `~firestudio.studios.gas_studio.GasStudio.set_ImageParams` for details.
+
+        Also calls the base method `firestudio.studios.studio.Studio.plotImage`. 
+
+        Parameters
+        ----------
+        ax : plt.Axes
+            axis to plot image to 
+        final_image : np.ndarray
+            array of RGB image pixel values
+        """
 
         ## run Studio's plotImage method
         super().plotImage(ax,final_image)
@@ -658,19 +689,9 @@ gasStudio.render(
                 fontsize=self.fontsize,
                 cmap_number=0.25)
 
-append_function_docstring(GasStudio,GasStudio.set_ImageParams)
-append_function_docstring(GasStudio,GasStudio.weightAvgAlongLOS)
-append_function_docstring(GasStudio,GasStudio.massWeightAlongLOS)
-append_function_docstring(GasStudio,GasStudio.volumeWeightAlongLOS)
-append_function_docstring(GasStudio,GasStudio.render)
-append_function_docstring(GasStudio,Studio)
-
-
 def getImageGrid(
-    BoxSize,
     Xmin,Xmax,
     Ymin,Ymax,
-    Zmin,Zmax,
     npix_x,npix_y,
     pos,weight,quantity,
     hsml,
