@@ -29,47 +29,71 @@ class StarStudio(Studio):
 * [`Studio.__init__`](#studio__init__) 
 * [`Studio.set_ImageParams`](#studioset_imageparams)"""
 
+    required_snapdict_keys = [
+        'Masses',
+        'Coordinates',
+        'SmoothingLength',
+        'Temperature',
+        'AgeGyr',
+        'Metallicity']
+
     def __repr__(self):
         return 'StarStudio instance'
 
 ####### makeOutputDirectories implementation #######
     def set_ImageParams(
         self,
-        use_defaults=False,
-        loud=True,
+        use_defaults:bool=False,
+        loud:bool=True,
         **kwargs):
-        """Changes the parameters of the image. If `use_defaults=True` then 
-            default values of the parameters will be set. Leave `use_defaults=False`
-            to adjust only the keywords passed. 
+        """Changes the parameters of the image. 
+         
 
-            Input: 
-
-                maxden = None --  controls the saturation of the image,
-                    sets the upper limit of the "colorbar," defaults to 
-                    the 99 %'ile of the image surface brightness
-                dynrange = None  --  controls the saturation of the image,
-                    sets the lower limit of the "colorbar" with respect to maxden,
-                    defaults to the dynamic range between maxden and the 10th %'ile
-                    of the image surface brightness
-                color_scheme_nasa = True -- flag for switching between Hubble vs. SDSS images
-                loud = True -- flagwhether print statements should show up on console.
+        Parameters
+        ----------
+        use_defaults : bool, optional
+            If `True` then default values of the parameters will be set 
+            (potentially overwriting any previously specified parameters). 
+            If `False` adjust only the keywords passed, by default False
+        loud : bool, optional
+            flag to print which parameters are being set/updated, by default True
             
-            Output: 
+        Keywords
+        --------
+        maxden : float
+             controls the saturation of the image,
+            sets the upper limit of the "colorbar" if None uses
+            the 99 %'ile of the image surface brightness, by default None
+        dynrange : float
+            controls the saturation of the image,
+            sets the lower limit of the "colorbar" with respect to maxden,
+            if None uses the dynamic range between maxden and the 10th %'ile
+            of the image surface brightness, by default None
+        nodust : bool
+            flag for whether dust attenuantion should be ignored, by default False
+        age_max_gyr : float
+            maximum age in Gyr to show stellar emission from. If None then emission from all star
+            particles is considered, by default None
+        
+        color_scheme_nasa : bool
+            flag for switching between Hubble vs. SDSS false color remapping, by default True
 
-                None
-
-Example usage:
-```python
-starStudio.set_ImageParams(
-    maxden=0.1,
-    dynrange=10,
-    figure_label='Hubble')
-```"""
+        Example usage:
+        --------------
+        ```python
+        starStudio.set_ImageParams(
+            maxden=0.1,
+            dynrange=10,
+            figure_label='Hubble')
+        ```
+        """
 
         default_kwargs = {
-            'maxden' : None, ## 
-            'dynrange' : None, ## controls the saturation of the image in a non-obvious way
-            'color_scheme_nasa' : True} ## flag to use nasa colors (vs. SDSS if false)
+            'maxden':None, ## 
+            'dynrange':None, ## controls the saturation of the image in a non-obvious way
+            'color_scheme_nasa':True,
+            'no_dust':False,
+            'age_max_gyr':None} ## flag to use nasa colors (vs. SDSS if false)
 
         for kwarg in list(kwargs.keys()):
             ## only set it here if it was passed
@@ -88,8 +112,9 @@ starStudio.set_ImageParams(
             else:
                 if (kwarg not in Studio.set_ImageParams.default_kwargs 
                     and kwarg != 'this_setup_id'):
-                    print(kwarg,'ignored. Did you mean something else?',
-                        default_kwargs.keys())
+                    if self.master_loud:
+                        print(kwarg,'ignored. Did you mean something else?',
+                            default_kwargs.keys())
 
         if use_defaults:
             ## set the remaining image parameters to their default values
@@ -102,24 +127,20 @@ starStudio.set_ImageParams(
 
         ## set any other image params here
         super().set_ImageParams(use_defaults=use_defaults,**kwargs)
+        if self.no_dust: self.this_setup_id+='_no_dust'
+        if self.age_max_gyr is not None: self.this_setup_id+='_age_max%0.3f'%self.age_max_gyr
 
     append_function_docstring(set_ImageParams,Studio.set_ImageParams,prepend_string='passes `kwargs` to:\n')
 
     def print_ImageParams(self):
-        """ Prints current image setup to console.
-
-            Input:
-
-                None
-
-            Output:
-
-                None"""
+        """ Prints current image setup to console."""
 
         default_kwargs = {
             'maxden' : 1.0e-2, ## 
             'dynrange' : 100.0, ## controls the saturation of the image in a non-obvious way
-            'color_scheme_nasa' : True} ## flag to use nasa colors (vs. SDSS if false)
+            'color_scheme_nasa' : True, ## flag to use nasa colors (vs. SDSS if false)
+            'no_dust':False,
+            'age_max_gyr':None} ## flag to use nasa colors (vs. SDSS if false)
 
         ## print the current value, not the default value
         for arg in default_kwargs:
@@ -130,21 +151,55 @@ starStudio.set_ImageParams(
 
     def quick_get_mockHubbleImage(
         self,
-        use_metadata=True,
-        save_meta=True,
-        assert_cached=False,
-        loud=True,
-        lums=None,
-        nu_effs=None,
-        BAND_IDS=None
+        lums:np.ndarray=None,
+        nu_effs:list=None,
+        BAND_IDS:list=None,
+        **kwargs
         ):
+        """Approximate the `~firestudio.studios.StarStudio.get_mockHubbleImage` routine using a 2d histogram.
+
+        Parameters
+        ----------
+        lums : np.ndarray, optional
+            array of luminosities for each star particle. If None then luminosities are calculated in
+            the bands specified by `BAND_IDS`, by default None
+        nu_effs : list, optional
+            list of effective frequencies corresponding to the bands of luminosities
+            provides in the `lums`. If None, uses the frequencies corresponding to the
+            specified `BAND_IDS`., by default None
+        BAND_IDS : list, optional
+            List of indices that identify which bands to model stellar emission in. 
+            If None uses Sloan UGR bands `(1,2,3)`, by default None
+            ```
+            lambda_eff=np.array([
+                ## Bolometric (?)
+                        1.e-5,  
+                ## SDSS u       g       r      i      z
+                        3551. , 4686. , 6165., 7481., 8931.,
+                ##      U       B       V      R
+                        3600. , 4400. , 5556., 6940., 
+                ##      I      J       H       K
+                        8700., 12150., 16540., 21790.])```
+
+        Returns
+        -------
+        np.ndarray
+            metal_mass_map - 2d map of metal mass used to attenuate luminosities
+            along LOS in pixel, in Msun/kpc^2
+        np.ndarray
+            out_0 - 2d map of luminosities in first band in Lsun/kpc^2
+        np.ndarray
+            out_1 - 2d map of luminosities in second band in Lsun/kpc^2
+        np.ndarray
+            out_2 - 2d map of luminosities in third band in Lsun/kpc^2
+        """
 
         if BAND_IDS is None:
             BAND_IDS=[1,2,3] ## used if corresponding column of lums is all 0s
        
         # apply filters, rotations, unpack snapshot data, etc...
         (kappas, lums,
-            star_pos, mstar, ages, metals, h_star,
+            star_pos, h_star,
             gas_pos , mgas , gas_metals ,  h_gas) = self.prepareCoordinates(lums,nu_effs,BAND_IDS)
 
         star_xs,star_ys,star_zs = star_pos.T
@@ -178,48 +233,38 @@ starStudio.set_ImageParams(
 
     def get_mockHubbleImage(
         self,
-        use_metadata=True,
-        save_meta=True,
-        assert_cached=False,
-        loud=True,
+        use_metadata:bool=True,
+        save_meta:bool=True,
+        assert_cached:bool=False,
+        loud:bool=True,
         **kwargs, 
         ):
         """Projects starlight and approximates attenuatation along line of sight
             into SDSS u, g, and r bands. 
 
-            Input:
+        Parameters
+        ----------
+        use_metadata : bool, optional
+            flag to search cache for result, by default True
+        save_meta : bool, optional
+            flag to cache the result, by default True
+        assert_cached : bool, optional
+            flag to raise an exception on a cache miss, by default False
+        loud : bool, optional
+            whether cache hits/misses should be announced to the console, by default True
 
-                use_metadata = True -- flag to search cache for result
-                save_meta = True -- flag to cache the result
-                assert_cached = False -- flag to require a cache hit
-                loud = True -- whether cache hits/misses should be announced
-                    to the console.
-
-                lums = None -- manual input for luminosities
-                nu_effs = None -- manual input for effective frequency of input luminosity band
-
-                BAND_IDS = None -- index for luminosity band to project.
-                    lambda_eff=np.array([
-                        ## Bolometric (?)
-                                1.e-5,  
-                        ## SDSS u       g       r      i      z
-                                3551. , 4686. , 6165., 7481., 8931.,
-                        ##      U       B       V      R
-                                3600. , 4400. , 5556., 6940., 
-                        ##      I      J       H       K
-                                8700., 12150., 16540., 21790.])
-
-                    BAND_IDS[i] is ignored if nu_effs[i] is not None
-
-            Output:
-
-                gas_out -- total mass along LOS in pixel, in msun/kpc^2
-                out_u -- total attenuated luminosity along LOS in pixel
-                    in u band, in Lsun/kpc^2
-                out_g -- total attenuated luminosity along LOS in pixel
-                    in g band, in Lsun/kpc^2
-                out_r -- total attenuated luminosity along LOS in pixel
-                    in r band, in Lsun/kpc^2"""
+        Returns
+        -------
+        np.ndarray
+            metal_mass_map - 2d map of metal mass used to attenuate luminosities
+            along LOS in pixel, in Msun/kpc^2
+        np.ndarray
+            out_0 - 2d map of luminosities in first band in Lsun/kpc^2
+        np.ndarray
+            out_1 - 2d map of luminosities in second band in Lsun/kpc^2
+        np.ndarray
+            out_2 - 2d map of luminosities in third band in Lsun/kpc^2
+        """
 
         @metadata_cache(
             self.this_setup_id,  ## hdf5 file group name
@@ -232,20 +277,24 @@ starStudio.set_ImageParams(
             assert_cached=assert_cached,
             loud=loud,
             force_from_file=True)  ## read from cache file, not attribute of object
-        def compute_mockHubbleImage(self,lums=None,nu_effs=None,BAND_IDS=None):
+        def compute_mockHubbleImage(
+            self:StarStudio,
+            lums:np.ndarray=None,
+            nu_effs:list=None,
+            BAND_IDS:list=None,
+            fixed_star_hsml=0.028):
 
             if BAND_IDS is None:
                 BAND_IDS=[1,2,3] ## used if corresponding column of lums is all 0s
             
             # apply filters, rotations, unpack snapshot data, etc...
             (kappas, lums,
-                star_pos, mstar, ages, metals, h_star,
-                gas_pos , mgas , gas_metals ,  h_gas) = self.prepareCoordinates(lums,nu_effs,BAND_IDS)
+                star_pos, h_star,
+                gas_pos , mgas , gas_metals ,  h_gas) = self.prepareCoordinates(lums,nu_effs,BAND_IDS,fixed_star_hsml)
 
             ## do the actual raytracing
             gas_out,out_u,out_g,out_r = raytrace_ugr_attenuation(
                 star_pos[:,0],star_pos[:,1],star_pos[:,2],
-                mstar,ages,metals,
                 h_star,
                 gas_pos[:,0],gas_pos[:,1],gas_pos[:,2],
                 mgas,gas_metals,h_gas,
@@ -263,48 +312,97 @@ starStudio.set_ImageParams(
         return compute_mockHubbleImage(self,**kwargs)
 
 
-    def prepareCoordinates(self,
-        lums=None,
-        nu_effs=None,
-        BAND_IDS=None):
+    def prepareCoordinates(
+        self,
+        lums:np.ndarray=None,
+        nu_effs:list=None,
+        BAND_IDS:list=None,
+        fixed_star_hsml:float=None):
+        """Reads snapshot data from `self.snapdict` and `self.star_snapdict` in the
+        imaging volume defined by `self.Xmin`,`self.Xmax`,`self.Ymin`,`self.Ymax`,`self.Zmin`,`self.Zmax`.
+        Unpacks necessary arrays and provides them to the calling imaging routine. 
+
+        Parameters
+        ----------
+        lums : np.ndarray, optional
+            array of luminosities for each star particle. If None then luminosities are calculated in
+            the bands specified by `BAND_IDS`, by default None
+        nu_effs : list, optional
+            list of effective frequencies corresponding to the bands of luminosities
+            provides in the `lums`. If None, uses the frequencies corresponding to the
+            specified `BAND_IDS`., by default None
+        BAND_IDS : list, optional
+            List of indices that identify which bands to model stellar emission in. 
+            If None uses Sloan UGR bands `(1,2,3)`, by default None
+            ```
+            lambda_eff=np.array([
+                ## Bolometric (?)
+                        1.e-5,  
+                ## SDSS u       g       r      i      z
+                        3551. , 4686. , 6165., 7481., 8931.,
+                ##      U       B       V      R
+                        3600. , 4400. , 5556., 6940., 
+                ##      I      J       H       K
+                        8700., 12150., 16540., 21790.])```
+
+        Returns
+        -------
+        np.ndarray(3)
+            kappas : array of effective cross sections in each band
+        np.ndarray(Nstar,3)
+            lums :  array of luminosities in each band
+        np.ndarray(Nstar,3)
+            star_pos : coordinate data for emitting stars in kpc 
+        np.ndarray(Ngas)
+            h_star : effective smoothing length/radius for each star particle in kpc
+        np.ndarray(Ngas,3)
+            gas_pos : coordinate data for attenuating gas in kpc
+        np.ndarray(Ngas)
+            mgas : mass data for attenuating gas in 10^10 Msun
+        np.ndarray(Ngas)
+            gas_metals : total metal mass fraction for each gas particle
+        np.ndarray(Ngas)
+            h_gas : smoothing length/radius for each gas particle in kpc
+        """
         
         ## unpack the star information
         ## dont' filter star positions just yet
         star_pos = self.star_snapdict['Coordinates']
 
-        ## rotate by euler angles if necessary
-        star_pos = self.camera.rotate_array(star_pos,offset=True)
-
         ## cull the particles outside the frame and cast to float32
-        star_ind_box = self.cullFrameIndices(star_pos)
-        if self.master_loud:
-            print(np.sum(star_ind_box),'many star particles in volume')
+        star_pos,star_mask = self.camera.project_and_clip(star_pos)
+
+        ages = self.star_snapdict['AgeGyr']
+        if self.age_max_gyr is not None:
+            star_mask = np.logical_and(star_mask,ages<self.age_max_gyr)
+        ages = ages[star_mask].astype(np.float32)
+        if self.master_loud: print(np.sum(star_mask),'many star particles in volume')
         
         ## try opening the stellar smoothing lengths, if we fail
         ##  let's calculate them and save them to the projection 
         ##  file
 
-        if "SmoothingLength" not in self.star_snapdict:
-            Hsml = self.get_HSML('star')
-            if Hsml.size != star_pos.shape[0]:
-                Hsml = self.get_HSML('star',use_metadata=False,save_meta=True)
+        if 'SmoothingLength' in self.star_snapdict:
+            Hsml = self.star_snapdict['SmoothingLength'] 
         else:
-            Hsml = self.star_snapdict['SmoothingLength'] ## kpc
+            if fixed_star_hsml is not None:
+                Hsml = np.repeat(fixed_star_hsml,star_pos.shape[0]) ## kpc
+            else:
+                Hsml = self.get_HSML('star')
+                if Hsml.size != star_pos.shape[0]:
+                    Hsml = self.get_HSML('star',use_metadata=False,save_meta=True)
+
         ## attempt to pass these indices along
-        h_star = Hsml[star_ind_box].astype(np.float32)
+        h_star = Hsml[star_mask].astype(np.float32)
 
-        ## and now filter the positions
-        star_pos = star_pos[star_ind_box].astype(np.float32)
-
-        mstar = self.star_snapdict['Masses'][star_ind_box].astype(np.float32)
-        ages = self.star_snapdict['AgeGyr'][star_ind_box].astype(np.float32)
+        mstar = self.star_snapdict['Masses'][star_mask].astype(np.float32)
         metals = self.star_snapdict['Metallicity']
         if len(np.shape(metals)) > 1: metals = metals[:,0]
-        metals = metals[star_ind_box].astype(np.float32)
+        metals = metals[star_mask].astype(np.float32)
 
         ## apply frame mask to band luminosities
         if lums is not None:
-            lums = lums[:,star_ind_box]
+            lums = lums[:,star_mask]
 
         ## will fill any columns of lums with appropriate BAND_ID 
         ##  if nu_eff for that column is not None
@@ -328,90 +426,62 @@ starStudio.set_ImageParams(
         KAPPA_UNITS=2.08854068444 ## cm^2/g -> kpc^2/mcode
         kappas = [KAPPA_UNITS*opacity_per_solar_metallicity(nu_eff) for nu_eff in nu_effs]
 
-
-        ## rotate by euler angles if necessary
-        gas_pos = self.camera.rotate_array(self.gas_snapdict['Coordinates'],offset=True)
-
         ## cull the particles outside the frame and cast to float32
-        gas_ind_box = self.cullFrameIndices(gas_pos)
-        if self.master_loud:
-            print(np.sum(gas_ind_box),'many gas particles in volume')
+        gas_pos,gas_mask = self.camera.project_and_clip(self.gas_snapdict['Coordinates'])
 
-        ## unpack the gas information
-        gas_pos = gas_pos[gas_ind_box].astype(np.float32)
+        if self.master_loud: print(np.sum(gas_mask),'many gas particles in volume')
 
-
-        mgas = self.gas_snapdict['Masses'][gas_ind_box].astype(np.float32)
+        mgas = self.gas_snapdict['Masses'][gas_mask].astype(np.float32)
         gas_metals = self.gas_snapdict['Metallicity']
         if len(np.shape(gas_metals)) > 1: gas_metals = gas_metals[:,0]
-        gas_metals = gas_metals[gas_ind_box].astype(np.float32)
+        gas_metals = gas_metals[gas_mask].astype(np.float32)
 
         ## set metallicity of hot gas to 0 so there is no dust extinction
-        temperatures = self.gas_snapdict['Temperature'][gas_ind_box]
+        temperatures = self.gas_snapdict['Temperature'][gas_mask]
         gas_metals[temperatures>1e5] = 0
 
         if "SmoothingLength" not in self.gas_snapdict:
-            h_gas = self.get_HSML('gas')[gas_ind_box]
+            h_gas = self.get_HSML('gas')[gas_mask]
         else:
-            h_gas = self.gas_snapdict['SmoothingLength'][gas_ind_box].astype(np.float32)
+            h_gas = self.gas_snapdict['SmoothingLength'][gas_mask].astype(np.float32)
+        
+        if self.no_dust: 
+            mgas = np.zeros(1)
+            gas_pos = np.zeros((1,3))
+            gas_metals = np.zeros(1)
+            h_gas = np.array([1e-3])
 
         return (kappas, lums,
-                star_pos, mstar, ages, metals, h_star,
+                star_pos, h_star,
                 gas_pos , mgas , gas_metals ,  h_gas)
 
 ####### produceImage implementation #######
-    def render(
-        self,
-        ax=None,
-        **kwargs):
-        """Plots a mock hubble image, along with any annotations/scale bars,
-            using the stored image parameters.
-
-            Input: 
-
-                ax = None -- axis to plot image to, if None will create a new figure
-                quick = False -- flag to use a simple 2d histogram (for comparison or
-                    for quick iteration as the user defines the image parameters)
-
-            Output:
-
-                ax -- the axis the image was plotted to
-                final_image -- 2x2x3 RGB pixel array
-
-Example usage:
-```python
-starStudio.render(plt.gca())
-```"""
-
-        if ax is None:
-            fig,ax = plt.figure(),plt.gca()
-        else:
-            fig = ax.get_figure()
-
-        ## remap the C output to RGB space
-        final_image = self.produceImage(**kwargs)
-
-        ## plot that RGB image and overlay scale bars/text
-        self.plotImage(ax,final_image)
-
-        ## save the image
-        if self.savefig is not None:
-            self.saveFigure(ax,self.savefig)
-
-        return ax,final_image
-
     def produceImage(
         self,
-        quick=False,
+        quick:bool=False,
         **kwargs):
+        """Generates a mock hubble image, along with any annotations/scale bars,
+            using the stored image parameters.
+
+        Parameters
+        ----------
+        quick : bool, optional
+            flag to use a simple 2d histogram (for comparison or for quick iteration 
+            as you choose image parameters), by default False
+
+        Returns
+        -------
+        np.ndarray(npix_x,npix_y,3)
+            RGB pixel array of the produced image
+        """
 
         if not quick:
             gas_out,out_u,out_g,out_r = self.get_mockHubbleImage(**kwargs)
         else:
             gas_out,out_u,out_g,out_r = self.quick_get_mockHubbleImage(**kwargs)
 
-        all_bands = np.concatenate([out_u,out_g,out_r])
-        maxden_guess,dynrange_guess = self.predictParameters(all_bands=all_bands)
+        L_sfc_densities = np.concatenate([out_u,out_g,out_r])
+        maxden_guess,dynrange_guess = self.predictParameters(L_sfc_densities=L_sfc_densities)
         if self.maxden is None:
             print("setting maxden to best guess %.2g"%maxden_guess)
             self.set_ImageParams(
@@ -442,44 +512,53 @@ starStudio.render(plt.gca())
 
     def predictParameters(
         self,
-        left_percentile=0.1,
-        right_percentile=0.99,
-        all_bands=None,
-        ax=None,
-        quick=False):
-        """ Guesses what the "best" values for maxden and dynrange are from
+        left_percentile:float=0.1,
+        right_percentile:float=0.99,
+        L_sfc_densities:np.ndarray=None,
+        ax:plt.Axes=None,
+        quick:bool=False):
+        """Guesses what the "best" values for maxden and dynrange are from
             the distribution of surface brightnesses in the current image. 
             Looks for the left_percentile and right_percentile and returns
             right_percentile and the distance between it and left_percentile
             (in log space). 
             
-            Input:
+        Parameters
+        ----------
+        left_percentile : float, optional
+            lower bound on image surface brightness percentile, by default 0.1
+        right_percentile : float, optional
+            upper bound on image surface brightness percentile, by default 0.99
+        L_sfc_densities : np.ndarray, optional
+            surface densities to find the percentiles of. If None uses 
+            `~firestudio.studios.star_studio.StarStudio.get_mockHubbleImage` to 
+            retrieve the surface densities of the projected mock hubble image, by default None
+        ax : plt.Axes, optional
+            axis to plot distribution of surface brightnesses
+            with overlay of percentiles and such to, by default None
+        quick : bool, optional
+            flag to use `~firestudio.studios.star_studio.StarStudio.quick_get_mockHubbleImage`, by default False
 
-                left_percentile = 0.1 -- lower bound on image surface brightness percentile
-                right_percentile = 0.99 --  upper bound on image surface brightness percentile
-                ax = None -- optionally plots distribution of surface brightnesses
-                    (in some units...) with overlay of percentiles and such.
-                quick = False -- flag to use a simple 2d histogram (for comparison or
-                    for quick iteration as the user defines the image parameters)
-            
-            Output:
-                
-                maxden -- maximum surface brightness of the image
-                dynrange -- distance between maximum and minimum surface brightness
-                     in log space. 
-"""
+        Returns
+        -------
+        float
+            maxden : maximum surface brightness of the image
+        float
+            dynrange : distance between maximum and minimum surface brightness
+                     in log space.
+        """
 
-        if (all_bands is None):
+        if (L_sfc_densities is None):
             ## read the luminosity maps
             if not quick:
                 gas_out,out_u,out_g,out_r = self.get_mockHubbleImage()
             else:
                 gas_out,out_u,out_g,out_r = self.quick_get_mockHubbleImage()
 
-            all_bands = np.concatenate([out_u,out_g,out_r])
+            L_sfc_densities = np.concatenate([out_u,out_g,out_r])
 
         ## concatenate the luminosity maps and take the log of the non-empty ones
-        rats = np.log10(all_bands.flatten())
+        rats = np.log10(L_sfc_densities.flatten())
         rats = rats[np.isfinite(rats)]
         h,edges = np.histogram(rats,bins=1000)
     
@@ -511,7 +590,11 @@ starStudio.render(plt.gca())
             ax.axvline(bottom,c='C1',ls='--',alpha=0.25)
             ax.axvline(top,c='C1')
             ax.text(np.sqrt(bottom*top),0.5/1.1,'dynrange',ha='center')
-            nameAxes(ax,None,"'den' (L$_\odot$ kpc$^{-2}$)","1/N dN/d('den')",logflag=(1,0),
+            nameAxes(
+                ax,None,
+                r"'den' (L$_\odot$ kpc$^{-2}$)",
+                r"1/N dN/d('den')",
+                logflag=(1,0),
                 supertitle="maxden=%.2g\ndynrange=%2d"%(maxden,dynrange))
             ax.get_figure().set_dpi(120)
 
@@ -525,49 +608,55 @@ starStudio.render(plt.gca())
             if self.dynrange is not None:
                 ax.plot([this_maxden/self.dynrange,this_maxden],[0.4,0.4],c='C2')
                 #ax.text(np.sqrt(this_maxden**2/self.dynrange),0.4/1.1,'dynrange',ha='center')
-
-
-
         return maxden,dynrange
 
     def plotParameterGrid(
         self,
-        dynrange_init=100,
-        maxden_init=1e-2,
-        dynrange_step=None,
-        maxden_step=None,
-        nsteps=4,
-        loud=False,
+        dynrange_init:float=1e2,
+        maxden_init:float=1e-2,
+        dynrange_step:float=None,
+        maxden_step:float=None,
+        nsteps:int=4,
         **kwargs):
         """ Plots a grid of images that steps in maxden and dynrange to help the user decide
             what values to use, based on their aesthetic preference. Step is applied
-            multiplicatively. 
+            multiplicatively. Accepts keyword arguments for 
+            `~firestudio.studios.star_studio.StarStudio.set_ImageParams`
 
-            Input:
+        Parameters
+        ----------
+        dynrange_init : float, optional
+            initial value in top left corner of grid, by default 1e2
+        maxden_init : float, optional
+            initial value in top left corner of grid, by default 1e-2
+        dynrange_step : float, optional
+            step between grid thumbnails, by default sqrt(10), by default None
+        maxden_step : float, optional
+            step between grid thumbnails, by default sqrt(10), by default None
+        nsteps : int, optional
+            number of steps in (square) thumbnail grid, by default 4
+        
+        Keywords
 
-                dynrange_init = 100 -- initial value in top left corner of grid
-                maxden_init = 1e-2 -- initial value in top left corner of grid
-                dynrange_step = None -- step between grid thumbnails, defaults to sqrt(10)
-                maxden_step = None -- step between grid thumbnails, defaults to sqrt(10)
-                nsteps = 4 -- number of steps in (square) thumbnail grid
-                loud = False -- flag for set_ImageParams
-                **kwargs -- kwargs passed to set_ImageParams
-            
-            Ouput:
-                
-                fig - the matplotlib figure drawn to
-                axs - the matplotlib axes in the grid
+        Returns
+        -------
+        plt.figure
+            fig : the matplotlib figure drawn to
+        list of plt.Axes
+            axs : the matplotlib axes in the grid
 
-Example usage:
-```python
-starStudio.plotParameterGrid(
-    dynrange_init=1e3,
-    maxden_init=1,
-    dynrange_step=.1,
-    maxden_step=.1,
-    nsteps=2,
-    use_colorscheme_nasa=False)
-```"""
+
+        Example usage:
+        --------------
+        ```python
+        starStudio.plotParameterGrid(
+            dynrange_init=1e3,
+            maxden_init=1,
+            dynrange_step=.1,
+            maxden_step=.1,
+            nsteps=2,
+            use_colorscheme_nasa=False)```
+        """
         
         ## initialize the steps for each thumbnail in the grid
         dynrange_step = 1/np.sqrt(10) if dynrange_step is None else dynrange_step
@@ -620,7 +709,6 @@ append_function_docstring(StarStudio,Studio)
 ## Stellar light attenuation projection
 def raytrace_ugr_attenuation(
     x,y,z,
-    mstar,ages,metals,
     h_star, 
     gx,gy,gz,
     mgas, gas_metals,
